JSPropertyDescriptor class

Constructors

JSPropertyDescriptor({dynamic value = _missingDescriptorValue, dynamic get, dynamic set, bool writable = true, bool enumerable = true, bool configurable = true, bool? hasWritable, bool? hasEnumerable, bool? hasConfigurable})

Properties

configurable bool
getter/setter pair
enumerable bool
getter/setter pair
get ↔ dynamic
getter/setter pair
hasConfigurable bool
getter/setter pair
hasEnumerable bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasValue bool
getter/setter pair
hasWritable bool
getter/setter pair
isAccessor bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
set ↔ dynamic
getter/setter pair
value ↔ dynamic
getter/setter pair
writable bool
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited