ControlFlowContinueException class

Inheritance

Constructors

ControlFlowContinueException(int line, String message, [String? label])

Properties

column ↔ int?
getter/setter pairinherited
detailedError ↔ String?
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
label → String?
final
line ↔ int
getter/setter pairinherited
message ↔ String
getter/setter pairinherited
originalError ↔ dynamic
getter/setter pairinherited
recovery ↔ String?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited