PropertyPattern class

Represents a key-value pattern resolved from a property access.

Constructors

PropertyPattern(Object obj, dynamic property)
Creates a property pattern with the given object and property.

Properties

hashCode int
The hash code for this object.
no setterinherited
obj Object
The target object of the property.
getter/setter pair
property ↔ dynamic
The key/property name.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited