View class

Constructors

View(String title, List<WidgetView> items, Map<String, WidgetView> idWidgetMap)

Properties

hashCode → int
The hash code for this object.
no setterinherited
idWidgetMap ↔ Map<String, WidgetView>
getter/setter pair
items ↔ List<WidgetView>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ String
getter/setter pair

Methods

get(String id) → WidgetView?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requireValue(String id) → WidgetView
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

from(YamlMap map) → View

Constants

PROPERTIES → const String